@@ -1,5 +1,5 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2012 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -401,7 +401,7 @@ static FILE *msgcache_open_data_file(const gchar *file, guint version,
 				     gchar *buf, size_t buf_size)
 {
 	FILE *fp;
-	gint32 data_ver = 0;
+	gint32 data_ver;
 
 	cm_return_val_if_fail(file != NULL, NULL);
 
@@ -1105,18 +1105,15 @@ static void msgcache_write_func(gpointer key, gpointer value, gpointer user_data
 gint msgcache_write(const gchar *cache_file, const gchar *mark_file, const gchar *tags_file, MsgCache *cache)
 {
 	struct write_fps write_fps;
-	gchar *new_cache = NULL, *new_mark = NULL, *new_tags = NULL;
+	gchar *new_cache, *new_mark, *new_tags;
 	int w_err = 0, wrote = 0;
 
 	START_TIMING("");
 	cm_return_val_if_fail(cache != NULL, -1);
 
-	if (cache_file)
-		new_cache = g_strconcat(cache_file, ".new", NULL);
-	if (mark_file)
-		new_mark  = g_strconcat(mark_file, ".new", NULL);
-	if (tags_file)
-		new_tags  = g_strconcat(tags_file, ".new", NULL);
+	new_cache = g_strconcat(cache_file, ".new", NULL);
+	new_mark  = g_strconcat(mark_file, ".new", NULL);
+	new_tags  = g_strconcat(tags_file, ".new", NULL);
 
 	write_fps.error = 0;
 	write_fps.cache_size = 0;
