@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2021 the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 2021-2022 the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -198,9 +198,9 @@ static gchar* oauth2_get_token_from_response(Oauth2Service provider, const gchar
                 token = g_strdup(response);
         } else {
                 gchar* start = g_strstr_len(response, strlen(response), OAUTH2CodeMarker[provider][0]);
-                start += strlen(OAUTH2CodeMarker[provider][0]);
                 if (start == NULL)
                         return NULL;
+                start += strlen(OAUTH2CodeMarker[provider][0]);
                 gchar* stop = g_strstr_len(response, strlen(response), OAUTH2CodeMarker[provider][1]);
                 if (stop == NULL)
                         return NULL;
@@ -215,8 +215,9 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
 	gchar *request;
 	gchar *response;
 	gchar *body;
+	gchar *uri, *uri2;
 	gchar *header;
-	gchar *tmp_hd;
+	gchar *tmp_hd, *tmp_hd_encoded;
 	gchar *access_token;
 	gchar *refresh_token;
 	gint expiry = 0;
@@ -225,7 +226,7 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
 	gchar *client_id;
 	gchar *client_secret;
     gchar *token = NULL;
-
+    gchar *tmp;
 	gint i;
 
 	i = (int)provider - 1;
@@ -235,7 +236,7 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
         token = oauth2_get_token_from_response(provider, authcode);
         debug_print("Auth token: %s\n", token);
         if (token == NULL) {
-                log_message(LOG_PROTOCOL, _("OAuth2 missing authentication code\n"));
+                log_message(LOG_PROTOCOL, _("OAuth2 missing authorization code\n"));
                 return (1);
         }
 
@@ -246,11 +247,12 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
                 return (1);
         }
         sock->ssl_cert_auto_accept = TRUE;
+	sock->use_tls_sni = TRUE;
 	sock_set_nonblocking_mode(sock, FALSE);
 	sock_set_io_timeout(10);
 	sock->gnutls_priority = "NORMAL:!VERS-SSL3.0:!VERS-TLS1.0:!VERS-TLS1.1";
         if (ssl_init_socket(sock) == FALSE) {
-                log_message(LOG_PROTOCOL, _("OAuth2 SSL connection error\n"));
+                log_message(LOG_PROTOCOL, _("OAuth2 TLS connection error\n"));
                 g_free(token);
                 return (1);
         }
@@ -258,16 +260,18 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
 	refresh_token = g_malloc(OAUTH2BUFSIZE+1);	
 	access_token = g_malloc(OAUTH2BUFSIZE+1);
 	request = g_malloc(OAUTH2BUFSIZE+1);
-	response = g_malloc(OAUTH2BUFSIZE+1);
-	body = g_malloc(OAUTH2BUFSIZE+1);
+	response = g_malloc0(OAUTH2BUFSIZE+1);
 
 	if(OAUTH2Data->custom_client_id)
 	  client_id = g_strdup(OAUTH2Data->custom_client_id);
 	else
 	  client_id = oauth2_decode(OAUTH2info[i][OA2_CLIENT_ID]);
-    
-	body = g_strconcat ("client_id=", g_uri_escape_string (client_id, NULL, FALSE), 
-			    "&code=",g_uri_escape_string (token, NULL, FALSE), NULL);
+
+	uri = g_uri_escape_string (client_id, NULL, FALSE);
+	uri2 = g_uri_escape_string (token, NULL, FALSE);
+	body = g_strconcat ("client_id=", uri, "&code=", uri2, NULL);
+    g_free(uri2);
+    g_free(uri);
     g_free(token);
 
 	if(OAUTH2info[i][OA2_CLIENT_SECRET][0]){
@@ -276,25 +280,56 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
 	    client_secret = g_strdup(OAUTH2Data->custom_client_secret);
 	  else
 	    client_secret = oauth2_decode(OAUTH2info[i][OA2_CLIENT_SECRET]);
-	  body = g_strconcat (body, "&client_secret=", g_uri_escape_string (client_secret, NULL, FALSE), NULL);
+	  uri = g_uri_escape_string (client_secret, NULL, FALSE);
+	  tmp = g_strconcat (body, "&client_secret=", uri, NULL);
+	  g_free(body);
+      g_free(uri);
+	  body = tmp;
 	}else{
 	  client_secret = g_strconcat ("", NULL);
 	}
 
-	if(OAUTH2info[i][OA2_REDIRECT_URI][0])
-	  body = g_strconcat (body, "&redirect_uri=",g_uri_escape_string (OAUTH2info[i][OA2_REDIRECT_URI], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_GRANT_TYPE_ACCESS][0])
-	  body = g_strconcat (body, "&grant_type=", g_uri_escape_string (OAUTH2info[i][OA2_GRANT_TYPE_ACCESS], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_TENANT][0])
-	  body = g_strconcat (body, "&tenant=", g_uri_escape_string (OAUTH2info[i][OA2_TENANT], NULL, FALSE), NULL);	
-	if(OAUTH2info[i][OA2_SCOPE_FOR_ACCESS][0])
-	  body = g_strconcat (body, "&scope=", g_uri_escape_string (OAUTH2info[i][OA2_SCOPE_FOR_ACCESS], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_STATE][0])
-	  body = g_strconcat (body, "&state=", g_uri_escape_string (OAUTH2info[i][OA2_STATE], NULL, FALSE), NULL);
+	if(OAUTH2info[i][OA2_REDIRECT_URI][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_REDIRECT_URI], NULL, FALSE);
+	  tmp = g_strconcat (body, "&redirect_uri=", uri, NULL);
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
+	}
+	if(OAUTH2info[i][OA2_GRANT_TYPE_ACCESS][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_GRANT_TYPE_ACCESS], NULL, FALSE);
+	  tmp = g_strconcat (body, "&grant_type=", uri, NULL);
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
+	}
+	if(OAUTH2info[i][OA2_TENANT][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_TENANT], NULL, FALSE);
+	  tmp = g_strconcat (body, "&tenant=", uri, NULL);
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
+	}
+	if(OAUTH2info[i][OA2_SCOPE_FOR_ACCESS][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_SCOPE_FOR_ACCESS], NULL, FALSE);
+	  tmp = g_strconcat (body, "&scope=", uri, NULL);
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
+	}
+	if(OAUTH2info[i][OA2_STATE][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_STATE], NULL, FALSE);
+	  tmp = g_strconcat (body, "&state=", uri, NULL);
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
+	}
 
 	if(OAUTH2info[i][OA2_HEADER_AUTH_BASIC][0]){
-	  tmp_hd = g_strconcat(client_id, ":", client_secret, NULL);	  
-	  header = g_strconcat ("Authorization: Basic ", g_base64_encode (tmp_hd, strlen(tmp_hd)), NULL);
+	  tmp_hd = g_strconcat(client_id, ":", client_secret, NULL);
+	  tmp_hd_encoded = g_base64_encode (tmp_hd, strlen(tmp_hd));
+	  header = g_strconcat ("Authorization: Basic ", tmp_hd_encoded, NULL);
+	  g_free(tmp_hd_encoded);
 	  g_free(tmp_hd);
 	}else{
 	  header = g_strconcat ("", NULL);
@@ -304,7 +339,7 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
 	ret = oauth2_contact_server (sock, request, response);
 
 	if(oauth2_filter_access (response, access_token, &expiry) == 0){
-	  OAUTH2Data->access_token = access_token;
+	  OAUTH2Data->access_token = g_strdup(access_token);
 	  OAUTH2Data->expiry = expiry;
 	  OAUTH2Data->expiry_str = g_strdup_printf ("%i", expiry);
 	  ret = 0;
@@ -316,7 +351,7 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
 	}
 
 	if(oauth2_filter_refresh (response, refresh_token) == 0){
-	  OAUTH2Data->refresh_token = refresh_token;
+	  OAUTH2Data->refresh_token = g_strdup(refresh_token);
 	  log_message(LOG_PROTOCOL, _("OAuth2 refresh token obtained\n"));
 	}else{
 	  log_message(LOG_PROTOCOL, _("OAuth2 refresh token not obtained\n"));
@@ -329,6 +364,8 @@ int oauth2_obtain_tokens (Oauth2Service provider, OAUTH2Data *OAUTH2Data, const
 	g_free(response);
 	g_free(client_id);
 	g_free(client_secret);
+	g_free(access_token);
+	g_free(refresh_token);
 
 	return (ret);
 }
@@ -339,15 +376,17 @@ gint oauth2_use_refresh_token (Oauth2Service provider, OAUTH2Data *OAUTH2Data)
 	gchar *request;
 	gchar *response;
 	gchar *body;
+	gchar *uri;
 	gchar *header;
-	gchar *tmp_hd;
+	gchar *tmp_hd, *tmp_hd_encoded;
 	gchar *access_token;
+	gchar *refresh_token;
 	gint expiry = 0;
 	gint ret;
 	SockInfo *sock;
 	gchar *client_id;
 	gchar *client_secret;
-
+	gchar *tmp;
 	gint i;
 
 	i = (int)provider - 1;
@@ -360,26 +399,28 @@ gint oauth2_use_refresh_token (Oauth2Service provider, OAUTH2Data *OAUTH2Data)
                 return (1);
         }
         sock->ssl_cert_auto_accept = TRUE;
+	sock->use_tls_sni = TRUE;
 	sock_set_nonblocking_mode(sock, FALSE);
 	sock_set_io_timeout(10);
 	sock->gnutls_priority = "NORMAL:!VERS-SSL3.0:!VERS-TLS1.0:!VERS-TLS1.1";
         if (ssl_init_socket(sock) == FALSE) {
-                log_message(LOG_PROTOCOL, _("OAuth2 SSL connection error\n"));
+                log_message(LOG_PROTOCOL, _("OAuth2 TLS connection error\n"));
                 return (1);
         }
 
 	access_token = g_malloc(OAUTH2BUFSIZE+1);
+	refresh_token = g_malloc(OAUTH2BUFSIZE+1);
 	request = g_malloc(OAUTH2BUFSIZE+1);
 	response = g_malloc(OAUTH2BUFSIZE+1);
-	body = g_malloc(OAUTH2BUFSIZE+1);
 
 	if(OAUTH2Data->custom_client_id)
 	  client_id = g_strdup(OAUTH2Data->custom_client_id);
 	else
 	  client_id = oauth2_decode(OAUTH2info[i][OA2_CLIENT_ID]);
 
-	body = g_strconcat ("client_id=", g_uri_escape_string (client_id, NULL, FALSE), 
-			    "&refresh_token=",OAUTH2Data->refresh_token, NULL); 
+	uri = g_uri_escape_string (client_id, NULL, FALSE);
+	body = g_strconcat ("client_id=", uri, "&refresh_token=", OAUTH2Data->refresh_token, NULL); 
+	g_free(uri);
 
 	if(OAUTH2info[i][OA2_CLIENT_SECRET][0]){
 	  //Only allow custom client secret if the service provider would usually expect a client secret
@@ -387,21 +428,42 @@ gint oauth2_use_refresh_token (Oauth2Service provider, OAUTH2Data *OAUTH2Data)
 	    client_secret = g_strdup(OAUTH2Data->custom_client_secret);
 	  else
 	    client_secret = oauth2_decode(OAUTH2info[i][OA2_CLIENT_SECRET]);
-	  body = g_strconcat (body, "&client_secret=", g_uri_escape_string (client_secret, NULL, FALSE), NULL);
+	  uri = g_uri_escape_string (client_secret, NULL, FALSE);
+	  tmp = g_strconcat (body, "&client_secret=", uri, NULL);
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
 	}else{
 	  client_secret = g_strconcat ("", NULL);
 	}
 
-	if(OAUTH2info[i][OA2_GRANT_TYPE_REFRESH][0])
-	  body = g_strconcat (body, "&grant_type=", g_uri_escape_string (OAUTH2info[i][OA2_GRANT_TYPE_REFRESH], NULL, FALSE), NULL);	
-	if(OAUTH2info[i][OA2_SCOPE_FOR_ACCESS][0])
-	  body = g_strconcat (body, "&scope=", g_uri_escape_string (OAUTH2info[i][OA2_SCOPE_FOR_ACCESS], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_STATE][0])
-	  body = g_strconcat (body, "&state=", g_uri_escape_string (OAUTH2info[i][OA2_STATE], NULL, FALSE), NULL);
+	if(OAUTH2info[i][OA2_GRANT_TYPE_REFRESH][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_GRANT_TYPE_REFRESH], NULL, FALSE);
+	  tmp = g_strconcat (body, "&grant_type=", uri, NULL);	
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
+	}
+	if(OAUTH2info[i][OA2_SCOPE_FOR_ACCESS][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_SCOPE_FOR_ACCESS], NULL, FALSE);
+	  tmp = g_strconcat (body, "&scope=", uri, NULL);
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
+	}
+	if(OAUTH2info[i][OA2_STATE][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_STATE], NULL, FALSE);
+	  tmp = g_strconcat (body, "&state=", uri, NULL);
+	  g_free(body);
+	  g_free(uri);
+	  body = tmp;
+	}
 
 	if(OAUTH2info[i][OA2_HEADER_AUTH_BASIC][0]){
-	  tmp_hd = g_strconcat(client_id, ":", client_secret, NULL);	  
-	  header = g_strconcat ("Authorization: Basic ", g_base64_encode (tmp_hd, strlen(tmp_hd)), NULL);
+	  tmp_hd = g_strconcat(client_id, ":", client_secret, NULL);
+	  tmp_hd_encoded = g_base64_encode (tmp_hd, strlen(tmp_hd));
+	  header = g_strconcat ("Authorization: Basic ", tmp_hd_encoded, NULL);
+	  g_free(tmp_hd_encoded);
 	  g_free(tmp_hd);
 	}else{
 	  header = g_strconcat ("", NULL);
@@ -411,7 +473,7 @@ gint oauth2_use_refresh_token (Oauth2Service provider, OAUTH2Data *OAUTH2Data)
 	ret = oauth2_contact_server (sock, request, response);
 
 	if(oauth2_filter_access (response, access_token, &expiry) == 0){
-	  OAUTH2Data->access_token = access_token;
+	  OAUTH2Data->access_token = g_strdup(access_token);
 	  OAUTH2Data->expiry = expiry;
 	  OAUTH2Data->expiry_str = g_strdup_printf ("%i", expiry);
 	  ret = 0;
@@ -422,6 +484,12 @@ gint oauth2_use_refresh_token (Oauth2Service provider, OAUTH2Data *OAUTH2Data)
 	  ret = 1;
 	}
 
+	if (oauth2_filter_refresh (response, refresh_token) == 0) {
+		OAUTH2Data->refresh_token = g_strdup(refresh_token);
+		log_message(LOG_PROTOCOL, _("OAuth2 replacement refresh token provided\n"));
+	} else
+		log_message(LOG_PROTOCOL, _("OAuth2 replacement refresh token not provided\n"));
+
 	debug_print("OAuth2 - access token: %s\n", access_token);
 	debug_print("OAuth2 - access token expiry: %i\n", expiry);
 	
@@ -432,6 +500,8 @@ gint oauth2_use_refresh_token (Oauth2Service provider, OAUTH2Data *OAUTH2Data)
 	g_free(response);
 	g_free(client_id);
 	g_free(client_secret);
+	g_free(access_token);
+	g_free(refresh_token);
 
 	return (ret);
 }
@@ -443,7 +513,7 @@ static gint oauth2_contact_server (SockInfo *sock, gchar *request, gchar *respon
 	gchar *token;
 	gint toread = OAUTH2BUFSIZE;	
 	time_t startplus = time(NULL);
-	
+	gchar *tmp;
 	len = strlen(request);
 	
 	startplus += 10;
@@ -465,11 +535,13 @@ static gint oauth2_contact_server (SockInfo *sock, gchar *request, gchar *respon
 	    break;
 	  
 	  toread -= ret;
-	  token = g_strconcat(token, response, NULL);
+	  tmp = g_strconcat(token, response, NULL);
+	  g_free(token);
+	  token = tmp;
 	} while ((toread > 0) && (time(NULL) < startplus)); 
 	
 	if(time(NULL) >= startplus)
-	  log_message(LOG_PROTOCOL, _("OAuth2 socket timeout error \n"));
+	  log_message(LOG_PROTOCOL, _("OAuth2 socket timeout error\n"));
 	
 	g_free(token);
 	
@@ -478,33 +550,68 @@ static gint oauth2_contact_server (SockInfo *sock, gchar *request, gchar *respon
 
 gint oauth2_authorisation_url (Oauth2Service provider, gchar **url, const gchar *custom_client_id)
 {
-        gint i;
-	const gchar *client_id;
+	gint i;
+	gchar *client_id = NULL;
+	gchar *tmp;
+	gchar *uri;
 
 	i = (int)provider - 1;
 	if (i < 0 || i > (OAUTH2AUTH_LAST-1))
 	  return (1);
 	
-	if(custom_client_id)
-	  client_id = custom_client_id;
-	else
+	if(!custom_client_id)
 	  client_id = oauth2_decode(OAUTH2info[i][OA2_CLIENT_ID]);
 	
+	uri = g_uri_escape_string (custom_client_id ? custom_client_id : client_id, NULL, FALSE);
 	*url = g_strconcat ("https://", OAUTH2info[i][OA2_BASE_URL],OAUTH2info[i][OA2_AUTH_RESOURCE], "?client_id=",
-			    g_uri_escape_string (client_id, NULL, FALSE), NULL);
-			    
-	if(OAUTH2info[i][OA2_REDIRECT_URI][0])
-	  *url = g_strconcat (*url, "&redirect_uri=", g_uri_escape_string (OAUTH2info[i][OA2_REDIRECT_URI], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_RESPONSE_TYPE][0])
-	  *url = g_strconcat (*url, "&response_type=",g_uri_escape_string (OAUTH2info[i][OA2_RESPONSE_TYPE], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_SCOPE_FOR_AUTH][0])
-	  *url = g_strconcat (*url, "&scope=", g_uri_escape_string (OAUTH2info[i][OA2_SCOPE_FOR_AUTH], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_TENANT][0])
-	  *url = g_strconcat (*url, "&tenant=", g_uri_escape_string (OAUTH2info[i][OA2_TENANT], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_RESPONSE_MODE][0])
-	  *url = g_strconcat (*url, "&response_mode=", g_uri_escape_string (OAUTH2info[i][OA2_RESPONSE_MODE], NULL, FALSE), NULL);
-	if(OAUTH2info[i][OA2_STATE][0])
-	  *url = g_strconcat (*url, "&state=", g_uri_escape_string (OAUTH2info[i][OA2_STATE], NULL, FALSE), NULL);
+			    uri, NULL);
+	g_free(uri);
+	if (client_id)
+	  g_free(client_id);
+
+	if(OAUTH2info[i][OA2_REDIRECT_URI][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_REDIRECT_URI], NULL, FALSE);
+	  tmp = g_strconcat (*url, "&redirect_uri=", uri, NULL);
+	  g_free(*url);
+	  *url = tmp;
+	  g_free(uri);
+    
+	}  
+	if(OAUTH2info[i][OA2_RESPONSE_TYPE][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_RESPONSE_TYPE], NULL, FALSE);
+	  tmp = g_strconcat (*url, "&response_type=", uri, NULL);
+	  g_free(*url);
+	  *url = tmp;
+	  g_free(uri);
+	}  
+	if(OAUTH2info[i][OA2_SCOPE_FOR_AUTH][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_SCOPE_FOR_AUTH], NULL, FALSE);
+	  tmp = g_strconcat (*url, "&scope=", uri, NULL);
+	  g_free(*url);
+	  *url = tmp;
+	  g_free(uri);
+	}  
+	if(OAUTH2info[i][OA2_TENANT][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_TENANT], NULL, FALSE);
+	  tmp = g_strconcat (*url, "&tenant=", uri, NULL);
+	  g_free(*url);
+	  *url = tmp;
+	  g_free(uri);
+	}  
+	if(OAUTH2info[i][OA2_RESPONSE_MODE][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_RESPONSE_MODE], NULL, FALSE);
+	  tmp = g_strconcat (*url, "&response_mode=", uri, NULL);
+	  g_free(*url);
+	  *url = tmp;
+	  g_free(uri);
+	}  
+	if(OAUTH2info[i][OA2_STATE][0]) {
+	  uri = g_uri_escape_string (OAUTH2info[i][OA2_STATE], NULL, FALSE);
+	  tmp = g_strconcat (*url, "&state=", uri, NULL);
+	  g_free(*url);
+	  *url = tmp;
+	  g_free(uri);
+	}  
 
 	return (0);
 }
@@ -515,6 +622,7 @@ gint oauth2_check_passwds (PrefsAccount *ac_prefs)
 	gint expiry;
 	OAUTH2Data *OAUTH2Data = g_malloc(sizeof(* OAUTH2Data)); 
 	gint ret;
+	gchar *acc;
 
 	oauth2_init (OAUTH2Data);
 
@@ -522,10 +630,13 @@ gint oauth2_check_passwds (PrefsAccount *ac_prefs)
 	OAUTH2Data->custom_client_secret = ac_prefs->oauth2_client_secret;
 	
 	if(passwd_store_has_password(PWS_ACCOUNT, uid, PWS_ACCOUNT_OAUTH2_EXPIRY)) {
-	  expiry = atoi(passwd_store_get_account(ac_prefs->account_id, PWS_ACCOUNT_OAUTH2_EXPIRY));
+	  acc = passwd_store_get_account(ac_prefs->account_id, PWS_ACCOUNT_OAUTH2_EXPIRY);
+	  expiry = atoi(acc);
+	  g_free(acc);
 	  if (expiry >  (g_get_real_time () / G_USEC_PER_SEC)){
 	    g_free(OAUTH2Data);
 	    log_message(LOG_PROTOCOL, _("OAuth2 access token still fresh\n"));
+	    g_free(uid);
 	    return (0);
 	  }
 	}
@@ -535,9 +646,10 @@ gint oauth2_check_passwds (PrefsAccount *ac_prefs)
 	  OAUTH2Data->refresh_token = passwd_store_get_account(ac_prefs->account_id, PWS_ACCOUNT_OAUTH2_REFRESH);
 	  ret = oauth2_use_refresh_token (ac_prefs->oauth2_provider, OAUTH2Data);
 	}else if (passwd_store_has_password(PWS_ACCOUNT, uid, PWS_ACCOUNT_OAUTH2_AUTH)) {
-	  log_message(LOG_PROTOCOL, _("OAuth2 trying for fresh access token with auth code\n"));
-	  ret = oauth2_obtain_tokens (ac_prefs->oauth2_provider, OAUTH2Data, 
-				      passwd_store_get_account(ac_prefs->account_id, PWS_ACCOUNT_OAUTH2_AUTH));
+	  log_message(LOG_PROTOCOL, _("OAuth2 trying for fresh access token with authorization code\n"));
+	  acc = passwd_store_get_account(ac_prefs->account_id, PWS_ACCOUNT_OAUTH2_AUTH);
+	  ret = oauth2_obtain_tokens (ac_prefs->oauth2_provider, OAUTH2Data, acc);
+	  g_free(acc);
 	}else{
 	  ret = 1;
 	}
@@ -549,10 +661,13 @@ gint oauth2_check_passwds (PrefsAccount *ac_prefs)
       if (ac_prefs->use_smtp_auth && ac_prefs->smtp_auth_type == SMTPAUTH_OAUTH2)
 	        passwd_store_set_account(ac_prefs->account_id, PWS_ACCOUNT_SEND, OAUTH2Data->access_token, FALSE);
 	  passwd_store_set_account(ac_prefs->account_id, PWS_ACCOUNT_OAUTH2_EXPIRY, OAUTH2Data->expiry_str, FALSE);
-	  log_message(LOG_PROTOCOL, _("OAuth2 access token updated\n"));
+	  //Some providers issue replacement refresh tokens with each access token. Re-store whether replaced or not. 
+	  passwd_store_set_account(ac_prefs->account_id, PWS_ACCOUNT_OAUTH2_REFRESH, OAUTH2Data->refresh_token, FALSE);
+	  log_message(LOG_PROTOCOL, _("OAuth2 access and refresh token updated\n"));  
 	}
 
 	g_free(OAUTH2Data);
+    g_free(uid);
 	
 	return (ret);
 }
