@@ -18,6 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
 #include "eggaccelerators.h"
 
 #include <string.h>
@@ -206,7 +208,7 @@ egg_accelerator_parse_virtual (const gchar            *accelerator,
                                EggVirtualModifierType *accelerator_mods)
 {
   guint keyval;
-  GdkModifierType mods;
+  EggVirtualModifierType mods;
   gint len;
   gboolean bad_keyval;
   
@@ -494,7 +496,7 @@ egg_keymap_virtualize_modifiers (GdkKeymap              *keymap,
                                  GdkModifierType         concrete_mods,
                                  EggVirtualModifierType *virtual_mods)
 {
-  GdkModifierType virtual;
+  EggVirtualModifierType virtual;
   int i;
   const EggModmap *modmap;
   
