@@ -1,5 +1,5 @@
-/* select-keys.c - GTK+ based key selection
- * Copyright (C) 2001-2019 Werner Koch (dd9jn) and the Claws Mail team
+/* select-keys.c - GTK based key selection
+ * Copyright (C) 2001-2022 Werner Koch (dd9jn) and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify        
  * it under the terms of the GNU General Public License as published by
@@ -206,13 +206,15 @@ set_row (GtkListStore *store, gpgme_key_t key, gpgme_protocol_t proto)
         s = ret_str;
     }
     name = g_strdup(s);
+    if (ret_str)
+        g_free(ret_str);
 
     if (proto == GPGME_PROTOCOL_CMS && (!key->uids->email || !*key->uids->email)) {
-	gpgme_user_id_t uid = key->uids->next;
-	if (uid)
-		s = uid->email;
-	else
-		s = key->uids->email;
+        gpgme_user_id_t uid = key->uids->next;
+        if (uid)
+            s = uid->email;
+        else
+            s = key->uids->email;
     } else {
         s = key->uids->email;
     }
@@ -224,6 +226,8 @@ set_row (GtkListStore *store, gpgme_key_t key, gpgme_protocol_t proto)
         s = ret_str;
     }
     address = g_strdup(s);
+    if (ret_str)
+        g_free(ret_str);
 
     switch (key->uids->validity)
       {
@@ -261,7 +265,7 @@ set_row (GtkListStore *store, gpgme_key_t key, gpgme_protocol_t proto)
 
     g_free(name);
     g_free(address);
-    g_free (algo_buf);
+    g_free(algo_buf);
 }
 
 static gpgme_key_t 
@@ -491,9 +495,9 @@ create_dialog (struct select_keys_s *sk)
      * Do_n't encrypt are different than the one in the stock Cancel
      * button */
     gtkut_stock_button_set_create (&bbox, 
-                                   &select_btn, _("_Select"),
-		   		   &other_btn, _("_Other"),
-		    		   &dont_encrypt_btn, _("Do_n't encrypt"));
+                                   &select_btn, NULL, _("_Select"),
+		   		   &other_btn, NULL, _("_Other"),
+		    		   &dont_encrypt_btn, NULL, _("Do_n't encrypt"));
     
     cancel_btn = gtk_button_new_with_mnemonic("_Cancel");
     gtk_widget_set_can_default(cancel_btn, TRUE);
@@ -705,7 +709,7 @@ use_untrusted (gpgme_key_t key, gpgme_user_id_t uid, gpgme_protocol_t proto)
 	       "Do you trust this key enough to use it anyway?"), 
 	       key->subkeys->keyid, key->uids->name, key->uids->email);
     aval = alertpanel(title, buf,
-	     _("_No"), _("_Yes"), NULL, ALERTFOCUS_FIRST);
+		      NULL, _("_No"), NULL, _("_Yes"), NULL, NULL, ALERTFOCUS_FIRST);
     g_free(buf);
     g_free(title);
     if (aval == G_ALERTALTERNATE)
